netapp_ontap.models.consistency_group_tiering API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_tiering`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupTieringSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupTiering object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `control: str POST PATCH`

    Storage tiering placement rules for the object.

    Valid choices:

    - allowed
    - best_effort
    - disallowed
    - required
  `object_stores: List[ConsistencyGroupConsistencyGroupsTieringObjectStores] GET POST PATCH`

    Object stores to use. Used for placement.

  `policy: str GET POST`

    Policy that determines whether the user data blocks of a volume in a FabricPool will be tiered to the cloud store when they become cold.
    FabricPool combines flash (performance tier) with a cloud store into a single aggregate. Temperature of a volume block increases if it is accessed frequently and decreases when it is not. Valid in POST or PATCH.
    all ‐ Allows tiering of both snapshots and active file system user data to the cloud store as soon as possible by ignoring the temperature on the volume blocks.
    auto ‐ Allows tiering of both snapshot and active file system user data to the cloud store
    none ‐ Volume blocks are not be tiered to the cloud store.
    snapshot_only ‐ Allows tiering of only the volume snapshots not associated with the active file system.
    The default tiering policy is "snapshot-only" for a FlexVol volume and "none" for a FlexGroup volume. The default minimum cooling period for the "snapshot-only" tiering policy is 2 days and for the "auto" tiering policy it is 31 days.

    Valid choices:

    - all
    - auto
    - backup
    - none
    - snapshot_only